% Aryeh Drager
% Math 53 Project

% Model with J variables
% Requires function: finddxdt.m

clear

j = 40; % number of points
dt = 0.05; % time step, in "pentadays" (1 pentaday := 5 days)
t_final = 0.4; % final time, in pentadays
t = 0:dt:t_final; % time vector
F = 8; % forcing term
iterations = length(t); % number of iterations
x = F.*ones(j,iterations); % initialize model

% perturb
x(20,1) = 1.001.*x(20,1);

% Use 4th-order Runge-Kutta method (RK4)
for n = 2:iterations
    x_j = squeeze(x(:,(n-1)));
    f1 = finddxdt(x_j,F);
    f2 = finddxdt(dt./2.*f1 + x_j,F);
    f3 = finddxdt(dt./2.*f2 + x_j,F);
    f4 = finddxdt(dt.*f3 + x_j,F);
    x(:,n) = x(:,(n-1)) + dt./6.*(f1 + 2.*(f2 + f3) + f4);
end

x_plot(1,:) = x(j,:);
x_plot(2:(j+1),:) = x(:,:);

for n = 1:iterations
    x_plot(:,n) = F - x_plot(:,n);
    perturbation_scaling = 5;
    x_plot(:,n) = x_plot(:,n).*perturbation_scaling;
    x_plot(:,n) = x_plot(:,n) + 5.*t(n);
end

figure(1)
plot(0:40,x_plot','b')
title('Reproduction of Fig. 1 in Lorenz-Emanuel')
xlabel('site')
ylabel('time from initialization (days)')
set(gca,'YDir','reverse')
axis([0 40 -0.05 2.20])
axis square


