function [x_new,J_new] = time1map(x_old,j,F,dt,t_final)

t = 0:dt:t_final; % time vector
iterations = length(t); % number of iterations
x = zeros(j,(iterations*2)); % initialize model
js = zeros(j,j,iterations);

x(:,1) = x_old;
js(:,:,1) = eye(j);

% Use 4th-order Runge-Kutta method (RK4)
for n = 2:(iterations*2)
    littledt = dt/2;
    x_j = squeeze(x(:,(n-1)));
    f1 = finddxdt(x_j,F);
    f2 = finddxdt((littledt./2.*f1 + x_j),F);
    f3 = finddxdt((littledt./2.*f2 + x_j),F);
    f4 = finddxdt((littledt.*f3 + x_j),F);
    x(:,n) = x(:,(n-1)) + littledt.*(f1 + 2.*f2 + 2.*f3 + f4)./6;
end

for n = 2:iterations
    m = 2.*n - 1;
    js_j = squeeze(js(:,:,(n-1)));
    x_j_old = squeeze(x(:,(m-2)));
    x_j_mix = squeeze(x(:,(m-1)));
    x_j_new = squeeze(x(:,(m)));
    ff1 = findDFdt(js_j,x_j_old);
    ff2 = findDFdt((dt./2.*ff1 + js_j),x_j_mix);
    ff3 = findDFdt((dt./2.*ff2 + js_j),x_j_mix);
    ff4 = findDFdt((dt.*ff3 + js_j),x_j_new);
    js(:,:,n) = js(:,:,(n-1)) + dt.*(ff1 + 2.*ff2 + 2.*ff3 + ff4)./6;
end

x_new = x(:,(iterations*2));
J_new = js(:,:,iterations);

end